#
# spec file for package ipmitool
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ipmitool
Requires:       OpenIPMI
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  readline-devel
%if 0%{?suse_version} >= 1210
BuildRequires:  systemd
%endif
Url:            http://ipmitool.sourceforge.net/
Summary:        Utility for IPMI Control
License:        BSD-3-Clause
Group:          System/Management
Version:        1.8.17
Release:        3.3
Source:         http://heanet.dl.sourceforge.net/sourceforge/%{name}/%{name}-%{version}.tar.bz2
Source1:        ipmievd.service
Source2:        ipmievd.sysconf
Patch3:         fwum_enhance_output.patch
Patch6:         fix_file_permissions.patch
Patch8:         several_more_compile_fixes.patch
Patch9:         ipmitool_adjust_suse.paths
Patch10:        0001-Incorporate-upstream-comments-to-289-add-whitespace.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# bmc-snmp-proxy needs /usr/sbin/snmpd
Requires:       net-snmp
# ToDo: Convert old init scripts to systemd with next submit iteration
%{?systemd_requires}

%description
This package contains a utility for interfacing with devices that
support the Intelligent Platform Management Interface specification. 
IPMI is an open standard for machine health, inventory, and remote
power control.

This utility can communicate with IPMI-enabled devices through either a
kernel driver such as OpenIPMI or over the RMCP LAN protocol defined in
the IPMI specification.  IPMIv2 adds support for encrypted LAN
communications and remote Serial-over-LAN functionality.

It provides commands for reading the Sensor Data Repository (SDR) and
displaying sensor values, displaying the contents of the System Event
Log (SEL), printing Field Replaceable Unit (FRU) information, reading
and setting LAN configuration, and chassis power control.



%prep
%setup -q
%patch3 -p1
%patch6 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1

%build
touch INSTALL NEWS
autoreconf -fiv
%configure --with-pic 
%{__make} %{?jobs:-j%jobs}

%install
make DESTDIR=$RPM_BUILD_ROOT install
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/ipmitool
# exchange-bmc-os-info service

install -D -m 0755 contrib/exchange-bmc-os-info.init.redhat "$RPM_BUILD_ROOT\
"/%{_sbindir}/exchange-bmc-os-info
install -D -m 0644 contrib/exchange-bmc-os-info.service.redhat "$RPM_BUILD_ROOT"/usr/lib/systemd/system/exchange-bmc-os-info.service
install -D -m 0644 contrib/exchange-bmc-os-info.sysconf "$RPM_BUILD_ROOT"/%{_sysconfdir}/exchange-bmc-os-info
ln -sf %_sbindir/service ${RPM_BUILD_ROOT}%{_sbindir}/rcexchange-bmc-os-info

# ipmievd service
install -D -m 644 %{S:1} "$RPM_BUILD_ROOT"/usr/lib/systemd/system/ipmievd.service
install -D -m 644 %{S:2} "$RPM_BUILD_ROOT"/%{_sysconfdir}/ipmievd
ln -sf %_sbindir/service ${RPM_BUILD_ROOT}%{_sbindir}/rcipmievd

# bmc-snmp-proxy
install -D -m 755 contrib/bmc-snmp-proxy         "$RPM_BUILD_ROOT"/%{_sbindir}/bmc-snmp-proxy
install -D -m 644 contrib/bmc-snmp-proxy.service "$RPM_BUILD_ROOT"/usr/lib/systemd/system/bmc-snmp-proxy.service
install -D -m 755 contrib/bmc-snmp-proxy.sysconf "$RPM_BUILD_ROOT"/%{_sysconfdir}/bmc-snmp-proxy
ln -sf %_sbindir/service ${RPM_BUILD_ROOT}%{_sbindir}/rcbmc-snmp-proxy

%clean
rm -rf $RPM_BUILD_ROOT

%if 0%{?suse_version} >= 1210
%pre
%service_add_pre bmc-snmp-proxy.service exchange-bmc-os-info.service ipmievd.service

%post
%service_add_post bmc-snmp-proxy.service exchange-bmc-os-info.service ipmievd.service

%preun
%service_del_preun bmc-snmp-proxy.service exchange-bmc-os-info.service ipmievd.service

%postun
%service_del_postun bmc-snmp-proxy.service exchange-bmc-os-info.service ipmievd.service
%endif

%files
%defattr(644,root,root)
%doc AUTHORS COPYING README
%{_datadir}/ipmitool
%attr(755,root,root) %{_bindir}/ipmitool
%attr(755,root,root) %{_sbindir}/ipmievd
%attr(755,root,root) %{_sbindir}/exchange-bmc-os-info
%attr(755,root,root) %{_sbindir}/bmc-snmp-proxy
%{_sbindir}/rcipmievd
%{_sbindir}/rcexchange-bmc-os-info
%{_sbindir}/rcbmc-snmp-proxy
%config(noreplace) %{_sysconfdir}/exchange-bmc-os-info
%config(noreplace) %{_sysconfdir}/bmc-snmp-proxy
%config(noreplace) %{_sysconfdir}/ipmievd
%{_prefix}/lib/systemd/system/exchange-bmc-os-info.service
%{_prefix}/lib/systemd/system/ipmievd.service
%{_prefix}/lib/systemd/system/bmc-snmp-proxy.service
%doc %{_mandir}/man1/*
%doc %{_mandir}/man8/*

%changelog
* Fri Jul 22 2016 trenn@suse.de
- Re-introduce dependency (Requires:) to OpenIPMI package.
  /etc/sysconfig/ipmi is needed. (bsc#989985, bsc#988443).
  This should stay SLE12 SP2 only for now, hopefully we get rid
  of the dependency properly in factory and merge it back at some point of
  time.
* Tue May  3 2016 trenn@suse.de
- Update to latest version: 1.8.17 (fate#320439, bsc#976123)
  D    ipmitool-1.8.10-implicit-fortify-decl.patch
  D    ipmitool-1_8_16_HEAD.patch
  D    latest_compile_fixes.patch
  D    ipmitool-sol_memleak.patch
- Remove whitespace changes from:
  M    0001-Incorporate-upstream-comments-to-289-add-whitespace.patch
* Thu Feb 25 2016 trenn@suse.de
- Update to latest ipmitool source code
  commit 9020b67347f46554009591ae91e4fa8875c65dfa
  Date:   Tue Jan 12 21:16:37 2016 +0500
- Fix memleak: bnc#968105
  Add: ipmitool-sol_memleak.patch
* Wed Feb 24 2016 ro@suse.de
- do not use systemd macros for non-systemd distributions
* Wed Oct 14 2015 trenn@suse.de
- Update to latest ipmitool source code
  commit 999cd0ad9192b19ec57574e7aca111571f4d21d8
  Date:   Fri Mar 6 09:03:05 2015 -0600
  and throw away patches that went mainline.
  * Remove: fix_dell_oem_exitcode
* Wed Mar 11 2015 trenn@suse.de
- Add correct exit code on Dell specific commands which did not get mainline
  yet (bnc#886184)
  * Add patch: fix_dell_oem_exitcode
* Thu Jan 15 2015 trenn@suse.de
- Update to latest ipmitool sources.
  This is version 1.8.15 (git tag: IPMITOOL_1_8_15) plus mainline patches up
  to commit 708be8bc450f907cddb6d9e4b83aee6ba67b7d04
  Date:   Fri Jan 9 12:48:35 2015 +0100
  * Add: latest_compile_fixes.patch
  * Add: ipmitool-1_8_15_HEAD.patch
  * Remove: automake-1.13.patch
  * Remove: sdradd_close_file_handle.patch
  * Remove: ipmitool-1.8.10-implicit-fortify-decl.patch
* Thu Mar  6 2014 trenn@suse.de
- Update to latest git head and do not split up version 1.8.13.tar.bz2 tarball
  and patch to latest git HEAD.
  Reason is that all files in the repository got moved up one directory level
  by git commit:
  c18ec02f3304ce2a889a50e378f07a4168af3884
  Date:   Wed Feb 5 17:30:32 2014
  Move all files one level up in the file hierarchy, to avoid the useless
  ipmitool directory.
  We want the latest git head asap, because otherwise additionally needed
  patches will never patch cleanly in mainline and our repo and would always
  need adjusting.
  I asked for a new version tag mainline. As soon this happened, the
  tarball name should again match with the exact mainline git tag.
  Remove/Delete:
  ipmitool_update_to_git_head_31_01_2014_b0aad15d67007c74b.patch
- Incorporate patch on request from Dell: fate#315996
  Add: 0001-Incorporate-upstream-comments-to-289-add-whitespace.patch
* Thu Feb 13 2014 trenn@suse.de
- Added 3 services:
    1) exchange-bmc-os-info - fate#315999
    Shows SLES string as OS in the service processor info
    2) bmc-snmp-proxy - fate#316000
    Exports sel (BMC Error log) via snmpd
    3) ipmievd - fate#316002
    Logs sel to syslog
  1. and 2. are very Dell specific and should not get enabled by default
  3. got converted to a native systemd service. Still needs autoconf
  adjusting to get send mainline
  1. and 2. have somewhat bigger Init V init scripts and time was not
  enough to convert them. Therefore they were added via insserv
  and friends as well
  Add ipmitool_adjust_suse.paths
- Updated to latest git version:
  Add ipmitool_update_to_git_head_31_01_2014_b0aad15d67007c74b.patch
* Fri Oct  4 2013 kkaempf@suse.com
- Update to 1.8.13
  Changes: many, see
  http://sourceforge.net/projects/ipmitool/files/ipmitool/1.8.13/
- drop patches included upstream
  * compile-fixes.patch
  * ekanalyzer_fix_wrong_type_comparison.patch
  * increase_possible_fw_file_size.patch
  * ipmitool-bigendian.patch
  * old-gcc-options.patch
* Tue Jul 16 2013 tchvatal@suse.com
- Run format_spec_file so it is up par with others.
* Wed May 15 2013 kkaempf@suse.com
- fix GCC 4.3 build
  * Adds patch: old-gcc-options.patch
* Mon Mar 18 2013 dvaleev@suse.com
- fix build on BE arches (ipmitool-bigendian.patch)
* Thu Feb 28 2013 kkaempf@suse.com
- Adapt to Automake 1.13
* Thu Feb 28 2013 kkaempf@suse.com
- Version 1.8.12 released 2012-08-09
  Changes: many, see
  http://ipmitool.cvs.sourceforge.net/viewvc/ipmitool/ipmitool/ChangeLog?revision=1.37&view=markup&pathrev=IPMITOOL_1_8_12
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue May  4 2010 meissner@suse.de
- add a missing return value in one error branch.
* Thu Mar  4 2010 ro@suse.de
- fix one more no-return-in-nonvoid-function issue in ipmievd.c
* Thu Sep 17 2009 trenn@suse.de
- Fixed several compiler warnings (bnc#371131, bnc#480347, bnc#439490,
  bnc#525831, bnc#534909) and quite some more.
* Tue Sep 15 2009 trenn@suse.de
- Update to version 1.8.11
- Fix segfault when doing firmware upgrades with too big FW files
- Be more verbose why a firmware update does not match
* Tue Oct 14 2008 crrodriguez@suse.de
- fix implicit-fortify-decl errors
* Fri Sep 26 2008 duwe@suse.de
- fix ugly code and sloppy programming found by RPMlint
* Fri Sep 12 2008 duwe@suse.de
- update to version 1.8.10 as requested in FATE#304431
  + remove fixes now in mainline
* Thu Jan 17 2008 duwe@suse.de
- Fix bugs 298222 and 144023 (arg checking and POH scaling)
* Thu Mar  8 2007 duwe@suse.de
- add new compile fixes
* Wed Mar  7 2007 duwe@suse.de
- update to 1.8.9, fixing ipmievd crashing.
  This was requesten in Bug#246456
* Fri Oct 13 2006 duwe@suse.de
- update to today's CVS state
  * might fix SoL issues (Fate #30911)
* Tue Oct 10 2006 duwe@suse.de
- update to 1.8.8 mainly various fixes:
  version 1.8.8
  * Fix segfaults in sensor data repository list
  * Fix ipmievd to open interface before daemonizing
  * Fix IPMIv1.5 authtype NONE to ignore supplied password
  * Fix cipher suite display bug in lan print
  * Fix typo in IPMIv2 SOL output when sending break
  * Fix improper LUN handling with Tyan SOL
  * Add LUN support to OpenIPMI interface
  * Add support for Kontron OEM commands
  * Update to Kontron Firmware Update command
  version 1.8.7
  * Remove nuclear clause from license
  * Add Sun OEM command for blades
  * Increase argument size for raw commands in shell/exec
  * Fix handling of LUNs for LAN interfaces
  * Add IPMIv2 SOL loopback test
  * Add support for IBM OEM SEL messages
  * Disable file paranoia checks on read files by default
  * Support IPMIv2 SOL on older Intel boxes
  * Display message and exit if keepalive fails during SOL
  * Add support for setting VLAN id and priority
  * Add support for FreeBSD OpenIPMI-compatible driver
  * Add support for IPMIv2 Firmware Firewall
  * Fix gcc4 compile warnings
  * Make ipmievd generate pidfile
  * Add initscripts for ipmievd
* Mon May 29 2006 kukuk@suse.de
- Fix type conversion bug in ipmi_pef.c [#173658]
* Fri May 26 2006 schwab@suse.de
- Add readline-devel to BuildRequires to enable shell command.
- Fix use of channel_info bitfield.
- Fix byte swapping.
* Mon Feb 13 2006 kukuk@suse.de
- Update to ipmitool 1.8.6 [#134708,#131823]
  - Fix memory corruption when sending encrypted SOL traffic
  - Add keepalive timer to IPMIv2 SOL sessions
  - Raise privilege level after creating IPMIv2 session
  - Add support for settable SOL escape character with -e option
  - Add support for Kg BMC key for IPMIv2 authentication with -k option
  - Add support for Tyan IPMIv1.5 SOL with tsol command
  - Add support for PICMG devices
  - Add support for OEM SEL event parsing
  - Add support for command bridging over lan and lanplus interfaces
  - New 'chassis selftest' command
  - Many bufxies and patches from contributors
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Mon Sep 19 2005 kukuk@suse.de
- Fix missing return value
* Thu Aug  4 2005 kukuk@suse.de
- Initial release (FeatureID #165)
